Audiology Data Base

# Info on Audiology Data Base

    WARNING: This database should be credited to the original owner whenever
             used for any publication whatsoever.

    1. Title: Audiology Database

    2. Sources:
        (a) Original Owner: Professor Jergen at Baylor College of Medicine
        (b) Donor: Bruce Porter (porter@fall.cs.utexas.EDU)
        (c) Date Received: 12/3/1987

    3. Past Usage:
       -- See: Bareiss, E. Ray, & Porter, Bruce (1987).  Protos: An Exemplar-Based
          Learning Apprentice.  In the Proceedings of the 4th International
          Workshop on Machine Learning, 12-23, Irvine, CA: Morgan Kaufmann.

    4. Relevant Information:
       -- Contact Ray Bareiss (rbareiss@uunet.uucp ??), now at Vanderbilt
          University, for more information.
       -- Domain expert: Professor Craig Wier of the University of Texas, Austin.

    5. Number of instances: 200 training cases, 26 test cases

    6. Number of attributes: ???

    7. Attribute information: (all attributes are nominally valued)
       1. case identifier.
       2. classification (24 classes)
       3. List of case features
          -- format: form f(v) should be read as "feature f has value v"

    8. Missing attribute values:
       -- This database does NOT use a standard set of attributes per instance.

    9. Class Distribution: (in the training set)
        1. acoustic_neuroma: 1
        2. bells_palsy: 1
        3. cochlear_age: 46
        4. cochlear_age_and_noise: 18
        5. cochlear_age_plus_poss_menieres: 1
        6. cochlear_noise_and_heredity: 2
        7. cochlear_poss_noise: 16
        8. cochlear_unknown: 48
        9. conductive_discontinuity: 2
       10. conductive_fixation: 6
       11. mixed_cochlear_age_fixation: 1
       12. mixed_cochlear_age_otitis_media: 4
       13. mixed_cochlear_age_s_om: 2
       14. mixed_cochlear_unk_discontinuity: 2
       15. mixed_cochlear_unk_fixation: 5
       16. mixed_cochlear_unk_ser_om: 3
       17. mixed_poss_central_om: 1
       18. mixed_poss_noise_om: 2
       19. normal_ear: 20
       20. otitis_media: 4
       21. poss_central: 1
       22. possible_brainstem_disorder: 4
       23. possible_menieres: 8
       24. retrocochlear_unknown: 2
       --------------------Total: 200